@@ -3,8 +3,6 @@
 super_csv Django application initialization.
 """
 
-from __future__ import absolute_import, unicode_literals
-
 from django.apps import AppConfig
 
 
@@ -24,4 +22,4 @@ class SuperCSVConfig(AppConfig):
     }
 
     def ready(self):
-        from . import signals  # pylint: disable=unused-import
+        from . import signals  # pylint: disable=unused-import, import-outside-toplevel
